==> db4o_7.4.121.14026+dfsg.orig.tar.gz: db4o-7.4.121.14026+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Jre5/Collections/Typehandler/ListTypeHandlerTestUnitBase.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using Db4objects.Db4o.Tests.Jre5.Collections.Typehandler;
using Db4objects.Db4o.Typehandlers;

namespace Db4objects.Db4o.Tests.Jre5.Collections.Typehandler
{
	public class ListTypeHandlerTestUnitBase : TypeHandlerTestUnitBase
	{
		protected override AbstractItemFactory ItemFactory()
		{
			return (AbstractItemFactory)ListTypeHandlerTestVariables.ListImplementation.Value;
		}

		protected override ITypeHandler4 TypeHandler()
		{
			return (ITypeHandler4)ListTypeHandlerTestVariables.ListTypehander.Value;
		}

		protected override void FillItem(object item)
		{
			FillListItem(item);
		}

		protected override void AssertContent(object item)
		{
			AssertListContent(item);
		}

		protected override ListTypeHandlerTestElementsSpec ElementsSpec()
		{
			return (ListTypeHandlerTestElementsSpec)ListTypeHandlerTestVariables.ElementsSpec
				.Value;
		}
	}
}

==> db4o_8.0.184.15484+dfsg.orig.tar.gz: db4o-8.0.184.15484+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Jre5/Collections/Typehandler/ListTypeHandlerTestUnitBase.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using System.Collections;
using Db4objects.Db4o.Tests.Jre5.Collections.Typehandler;
using Db4objects.Db4o.Typehandlers;

namespace Db4objects.Db4o.Tests.Jre5.Collections.Typehandler
{
	public class ListTypeHandlerTestUnitBase : TypeHandlerTestUnitBase
	{
		protected override AbstractItemFactory ItemFactory()
		{
			return (AbstractItemFactory)ListTypeHandlerTestVariables.ListImplementation.Value;
		}

		protected override ITypeHandler4 TypeHandler()
		{
			return (ITypeHandler4)ListTypeHandlerTestVariables.ListTypehander.Value;
		}

		protected override void FillItem(object item)
		{
			FillListItem(item);
		}

		protected override void AssertContent(object item)
		{
			AssertListContent(item);
		}

		protected override void AssertPlainContent(object item)
		{
			AssertPlainListContent((IList)item);
		}

		protected override ListTypeHandlerTestElementsSpec ElementsSpec()
		{
			return (ListTypeHandlerTestElementsSpec)ListTypeHandlerTestVariables.ElementsSpec
				.Value;
		}
	}
}
